from distutils.core import setup
setup(
name = 'dsomesh',
version = '1.0.0',
py_modules = ['dsomesh'],
author = 'dsomesh',
author_email = 'meetsomesh01@gmail.com',
url = 'http://www.headfirstlabs.com',
description = 'A simple printer of nested lists',
keywords = ['testing', 'logging', 'example'],
classifiers = [],
)